Welcome to flatland's documentation!
======================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   01_readme
   03_tutorials_toc
   04_specifications_toc
   05_apidoc
   06_contributing
   07_changes
   08_authors

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
